@@ -16,6 +16,9 @@ EOF
 exit
 fi
 dir=$1
+if [ ! -d $dir ]; then
+    mkdir -p $dir
+fi
 shift
 for f in $*; do
     echo $f
