@@ -7,7 +7,8 @@
            	        ! If <0, abs is used. neutral ptcl tracks also recorded
 			      
        character*128 TraceDir   ! The director where you take trace info
-
+       character*128 ModifyFile ! some component must have non default
+	 ! quenching, Emin  etc.  This file contains such info.
        integer MaxMediaDir  ! max number of directories where
                             ! media file is searched for.
        integer MsgLevel     ! 0,1,or 2.  0-->only fatal error is shown
@@ -25,4 +26,4 @@
        common /epManag/ epHookr, epHooki, epHooks,
      *  Nevrun, MsgLevel, IoTrace, DoUpdateNo
 
-       common /epManagC/ MediaDir, TraceDir, epHookc
+        common /epManagC/ MediaDir, TraceDir, ModifyFile, epHookc
